import os
import logging

import dotenv

from core.exceptions import ConfigError

dotenv.load_dotenv()


class BankNodeConfig:
    def __init__(self):
        self.logger = logging.getLogger(__name__)
        port = os.getenv("PORT", "65526")
        timeout = os.getenv("RESPONSE_TIMEOUT", "5")
        verbosity = os.getenv("VERBOSITY", "INFO")
        scan_port_range = os.getenv("SCAN_PORT_RANGE")

        if not scan_port_range or scan_port_range == "":
            self.logger.error("Scan port range not defined")
            raise ConfigError("Scan port range not defined")

        range_split = scan_port_range.split(":")

        if len(range_split) != 2 or not range_split[0].isdigit() or not range_split[1].isdigit():
            self.logger.error("Scan port range is not in valid format")
            raise ConfigError("Scan port range is not in valid format")


        if not port.isdigit():
            self.logger.warning("Application port is invalid - Not a number. Falling back to default port 65526")

        if not timeout.isdigit():
            self.logger.warning("Request timeout is invalid - Not a number. Falling back to default timeout 5 seconds")

        allowed_levels = logging.getLevelNamesMapping()

        if verbosity not in allowed_levels:
            self.logger.warning("Verbosity %s is invalid - Doesn't exist. Falling back to default verbosity INFO", verbosity)

        self.port = int(port)
        self.timeout = int(timeout)
        self.verbosity = verbosity
        self.scan_port_start = int(range_split[0])
        self.scan_port_end = int(range_split[1])
